panelsToList: Convert joined panel into seperate lists, that can be fed to...

Description Usage Arguments Value

Description

Convert joined panel into seperate lists, that can be fed to the igft interpolator

Usage

1
panelsToList(panel.names, noisy = TRUE)

Arguments

panel.names

Vector of panel names that will be loaded and parsed

Value

Returns a list with components p.list, m.list and days.all. These correspond daily priceMat panel lists, daily market frames and the vector of available days.


piotrek-orlowski/impliedCF documentation built on May 7, 2019, 8:18 a.m.