Description Usage Arguments Value
Convert joined panel into seperate lists, that can be fed to the igft interpolator
1 | panelsToList(panel.names, noisy = TRUE)
|
panel.names |
Vector of panel names that will be loaded and parsed |
Returns a list with components p.list, m.list and days.all. These correspond daily priceMat panel lists, daily market frames and the vector of available days.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.